==> savane-1.0.3.1.tar.gz: savane/frontend/php/register/projectname.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: projectname.php,v 1.30 2004/06/26 10:44:32 yeupou Exp $
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2000-2003 (c) Free Software Foundation
#                          Mathieu Roy <yeupou--at--gnu.org>
#
#  Copyright 2004      (c) ...
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

require "../include/pre.php";    

session_require(array('isloggedin'=>'1'));

require  $GLOBALS['sys_urlroot']."/include/account.php";

# push received vars
if ($insert_purpose && $form_purpose) { 

	srand((double)microtime()*1000000);
	$random_num=rand(0,1000000);

	# make group entry
	$result = db_query("INSERT INTO groups (group_name,is_public,unix_group_name,http_domain,status,license,register_purpose,required_software,other_comments,register_time,license_other,rand_hash) VALUES ("
		. "'__$random_num',"
		. "1," # public
		. "'__$random_num',"
		. "'__$random_num',"
		. "'D'," # status set to deleted until the registration is complete
		. "'__$random_num',"
		. "'".htmlspecialchars($form_purpose)."',"
		. "'".htmlspecialchars($form_required_sw)."',"
		. "'".htmlspecialchars($form_comments)."',"
		. time() . ","
		. "'__$random_num','__".md5($random_num)."')");

	if (!$result) {
		exit_error('ERROR','INSERT QUERY FAILED. Please notify admin@'.$GLOBALS['sys_default_domain']);
	} else {
		$group_id=db_insertid($result);
	}

} elseif (!$form_full_name && !$form_unix_name) {
	exit_error('Error','Missing Information. <B>PLEASE</B> fill in all required information.');
}

# FIXME: begin
# we test project name
#if ($form_full_name && $form_unix_name) {
#  utils_get_content("register/projectname_test");
#  #  print 'debug '.projectname_do_the_test($test_on_name=$test_on_name, $form_unix_name=$form_unix_name, $form_full_name=$form_full_name).' debug';
#  if (projectname_do_the_test($test_on_name=$test_on_name, $form_unix_name=$form_unix_name, $form_full_name=$form_full_name) == "0") {
#    # if we get here, test has been done, we go to the next step
#    Header("Location: license.php?group_id=$group_id&insert_group_name=$insert_group_name&form_full_name=$form_full_name&form_unix_name=$form_unix_name&no_redirection=$no_redirection&re_license_other=$re_license_other&rand_hash=$rand_hash");
#  } else {
#    # if we get here, test was not ok
#    $need_to_print_warning = "1";
#    $test_on_name = "1";
#    $re_unix_name = $form_unix_name;
#    $re_full_name = $form_full_name;
#  }
#}
# FIXME: end

$HTML->header(array('title'=>_("Project Name")));

print '<h2>'._("Step").' 3: '._("Project Name").'</h2>';

# get site-specific content
utils_get_content("register/projectname");

# FIXME: begin
#if ($need_to_print_warning) {
#  print '<p><font class="error">'.projectname_test_error_message().'</font>';
#}
# FIXME: end


print '<p>'._("Please complete both fields").'.</p>';

print '<form action="license.php" method="post">';

# avoid pre.php looking for group_type info
print '<input type="hidden" name="no_redirection" value="1">';


#FIXME
#if (isset($test_on_name)) { echo '<input type="hidden" name="test_on_name" value="'.$test_on_name.'">'; }

if (isset($re_license_other)) { echo '<input type="hidden" name="re_license_other" value="'.$re_license_other.'">'; }

print '<input type="hidden" name="insert_group_name" value="y">';
print '<input type="hidden" name="group_id" value="'.$group_id.'">';
print '<input type="hidden" name="rand_hash" value="'.(isset($rand_hash) ? $rand_hash : md5($random_num)).'">';

print '<h3>'._("Full Name").' :</h3>';
print '<input size="60" maxlength="254" type="text" name="form_full_name"'.(isset($re_full_name) ? " value=\"$re_full_name\"":"").'>';


print '<h3>'._("System Name").' :</h3>';
print '<input type="text" maxlength="16" size="15" name="form_unix_name"'.(isset($re_unix_name) ? " value=\"$re_unix_name\"":"").'>';


print '<div align="center"><font class="error">'._("Do not click back button after this point").' !!</font></div>';

print '<div align="center">';
print '<h3>'._("Proceed to Next Step").' :</h3>';
print '<input type=submit name="Submit" value="'._("Step").' 4: '._("License").'">';
print '</div>';
print '</form>';

$HTML->footer(array());
?>

==> savane-1.0.4.2.tar.gz: savane/frontend/php/register/projectname.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: projectname.php,v 1.32 2004/09/23 12:16:34 yeupou Exp $
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2000-2003 (c) Free Software Foundation
#                          Mathieu Roy <yeupou--at--gnu.org>
#
#  Copyright 2004      (c) Mathieu Roy <yeupou--at--gnu.org>
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

require "../include/pre.php";    

session_require(array('isloggedin'=>'1'));

require  $GLOBALS['sys_urlroot']."/include/account.php";

# push received vars
if ($insert_purpose && $form_purpose) { 

	srand((double)microtime()*1000000);
	$random_num=rand(0,1000000);

	# make group entry
	$result = db_query("INSERT INTO groups (group_name,is_public,unix_group_name,status,license,register_purpose,required_software,other_comments,register_time,license_other,rand_hash) VALUES ("
		. "'__$random_num',"
		. "1," # public
		. "'__$random_num',"
		. "'I'," # status set to inactive until the registration is complete
		. "'__$random_num',"
		. "'".htmlspecialchars($form_purpose)."',"
		. "'".htmlspecialchars($form_required_sw)."',"
		. "'".htmlspecialchars($form_comments)."',"
		. time() . ","
		. "'__$random_num','__".md5($random_num)."')");

	if (!$result) {
		exit_error('ERROR','INSERT QUERY FAILED. Please notify '.$GLOBALS['sys_mail_admin'].'@'.$GLOBALS['sys_mail_domain']);
	} else {
		$group_id=db_insertid($result);
	}

} elseif (!$form_full_name && !$form_unix_name) {
	exit_error('Error','Missing Information. <B>PLEASE</B> fill in all required information.');
}

# FIXME: begin
# we test project name
#if ($form_full_name && $form_unix_name) {
#  utils_get_content("register/projectname_test");
#  #  print 'debug '.projectname_do_the_test($test_on_name=$test_on_name, $form_unix_name=$form_unix_name, $form_full_name=$form_full_name).' debug';
#  if (projectname_do_the_test($test_on_name=$test_on_name, $form_unix_name=$form_unix_name, $form_full_name=$form_full_name) == "0") {
#    # if we get here, test has been done, we go to the next step
#    Header("Location: license.php?group_id=$group_id&insert_group_name=$insert_group_name&form_full_name=$form_full_name&form_unix_name=$form_unix_name&no_redirection=$no_redirection&re_license_other=$re_license_other&rand_hash=$rand_hash");
#  } else {
#    # if we get here, test was not ok
#    $need_to_print_warning = "1";
#    $test_on_name = "1";
#    $re_unix_name = $form_unix_name;
#    $re_full_name = $form_full_name;
#  }
#}
# FIXME: end

$HTML->header(array('title'=>_("Project Name")));

print '<h2>'._("Step").' 3: '._("Project Name").'</h2>';

# get site-specific content
utils_get_content("register/projectname");

# FIXME: begin
#if ($need_to_print_warning) {
#  print '<p><font class="error">'.projectname_test_error_message().'</font>';
#}
# FIXME: end


print '<p>'._("Please complete both fields").'.</p>';

print '<form action="license.php" method="post">';

# avoid pre.php looking for group_type info
print '<input type="hidden" name="no_redirection" value="1">';


#FIXME
#if (isset($test_on_name)) { echo '<input type="hidden" name="test_on_name" value="'.$test_on_name.'">'; }

if (isset($re_license_other)) { echo '<input type="hidden" name="re_license_other" value="'.$re_license_other.'">'; }

print '<input type="hidden" name="insert_group_name" value="y">';
print '<input type="hidden" name="group_id" value="'.$group_id.'">';
print '<input type="hidden" name="rand_hash" value="'.(isset($rand_hash) ? $rand_hash : md5($random_num)).'">';

# If we are creating the local admin project, system unix group name cannot be
# changed and we make a proposal for the full name
if (!group_getid($GLOBALS['sys_unix_group_name']))
{
  print '<h3>'._("Full Name").' :</h3>';
  print '<input size="60" maxlength="254" type="text" name="form_full_name" value="Local Administration">';

  print '<h3>'._("System Name").' :</h3>';
  print '<input type="hidden" name="form_unix_name" value="'.$GLOBALS['sys_unix_group_name'].'"><b>'.$GLOBALS['sys_unix_group_name'].'</b>';
}
else
{
  print '<h3>'._("Full Name").' :</h3>';
  print '<input size="60" maxlength="254" type="text" name="form_full_name"'.(isset($re_full_name) ? " value=\"$re_full_name\"":"").'>';
  
  print '<h3>'._("System Name").' :</h3>';
  print '<input type="text" maxlength="16" size="15" name="form_unix_name"'.(isset($re_unix_name) ? " value=\"$re_unix_name\"":"").'>';
}
  
print '<div align="center"><font class="error">'._("Do not click back button after this point").' !!</font></div>';

print '<div align="center">';
print '<h3>'._("Proceed to Next Step").' :</h3>';
print '<input type=submit name="Submit" value="'._("Step").' 4: '._("License").'">';
print '</div>';
print '</form>';

$HTML->footer(array());
?>
